pub struct AxisIterMut<'a, A, D> { /* private fields */ }Expand description
An iterator that traverses over an axis and and yields each subview (mutable)
The outermost dimension is Axis(0), created with .outer_iter(),
but you can traverse arbitrary dimension with .axis_iter().
For example, in a 3 × 5 × 5 array, with axis equal to Axis(2),
the iterator element is a 3 × 5 subview (and there are 5 in total).
Iterator element type is ArrayViewMut<'a, A, D>.
See .outer_iter_mut()
or .axis_iter_mut()
for more information.
Implementations
Sourceimpl<'a, A, D> AxisIterMut<'a, A, D>where
D: Dimension,
impl<'a, A, D> AxisIterMut<'a, A, D>where
D: Dimension,
Sourcepub fn split_at(
self,
index: usize,
) -> (AxisIterMut<'a, A, D>, AxisIterMut<'a, A, D>)
pub fn split_at( self, index: usize, ) -> (AxisIterMut<'a, A, D>, AxisIterMut<'a, A, D>)
Splits the iterator at index, yielding two disjoint iterators.
index is relative to the current state of the iterator (which is not
necessarily the start of the axis).
Panics if index is strictly greater than the iterator’s remaining
length.