pub trait DimMax<Other>where Other: Dimension,{ type Output: Dimension; }
The resulting dimension type after broadcasting.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Dimensions of the same type remain unchanged when co_broadcast. So you can directly use D as the resulting type. (Instead of <D as DimMax<D>>::BroadcastOutput)
D
<D as DimMax<D>>::BroadcastOutput