pub trait ShapeArg {
type Dim: Dimension;
// Required method
fn into_shape_and_order(self) -> (Self::Dim, Option<Order>);
}Expand description
Array shape argument with optional order parameter
Shape or array dimension argument, with optional Order parameter.
This is an argument conversion trait that is used to accept an array shape and (optionally) an ordering argument.
See for example .to_shape().
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".