Display

Trait Display 

1.36.0 · Source
pub trait Display {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
Format trait for an empty format, {}.

Implementing this trait for a type will automatically implement the ToString trait for the type, allowing the usage of the .to_string() method. Prefer implementing the Display trait for a type, rather than ToString.

Display is similar to Debug, but Display is for user-facing output, and so cannot be derived.

For more information on formatters, see the module-level documentation.

Completeness and parseability

Display for a type might not necessarily be a lossless or complete representation of the type. It may omit internal state, precision, or other information the type does not consider important for user-facing output, as determined by the type. As such, the output of Display might not be possible to parse, and even if it is, the result of parsing might not exactly match the original value.

However, if a type has a lossless Display implementation whose output is meant to be conveniently machine-parseable and not just meant for human consumption, then the type may wish to accept the same format in FromStr, and document that usage. Having both Display and FromStr implementations where the result of Display cannot be parsed with FromStr may surprise users.

Internationalization

Because a type can only have one Display implementation, it is often preferable to only implement Display when there is a single most “obvious” way that values can be formatted as text. This could mean formatting according to the “invariant” culture and “undefined” locale, or it could mean that the type display is designed for a specific culture/locale, such as developer logs.

If not all values have a justifiably canonical textual format or if you want to support alternative formats not covered by the standard set of possible formatting traits, the most flexible approach is display adapters: methods like str::escape_default or Path::display which create a wrapper implementing Display to output the specific display format.

Examples

Implementing Display on a type:

use std::fmt;

struct Point {
    x: i32,
    y: i32,
}

impl fmt::Display for Point {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.x, self.y)
    }
}

let origin = Point { x: 0, y: 0 };

assert_eq!(format!("The origin is: {origin}"), "The origin is: (0, 0)");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Examples
use std::fmt;

struct Position {
    longitude: f32,
    latitude: f32,
}

impl fmt::Display for Position {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.longitude, self.latitude)
    }
}

assert_eq!(
    "(1.987, 2.983)",
    format!("{}", Position { longitude: 1.987, latitude: 2.983, }),
);

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Display for !

1.26.0 · Source

impl Display for AccessError

1.4.0 · Source

impl Display for AddrParseError

Source

impl Display for AllocError

1.0.0 · Source

impl Display for Arguments<'_>

Source

impl Display for AsciiChar

Source

impl Display for Assertion

Source

impl Display for Ast

Print a display representation of this Ast.

This does not preserve any of the original whitespace formatting that may have originally been present in the concrete syntax from which this Ast was generated.

This implementation uses constant stack space and heap space proportional to the size of the Ast.

Source

impl Display for AxesMapping

1.65.0 · Source

impl Display for Backtrace

Source

impl Display for BigEndian

Source

impl Display for Blob

Source

impl Display for BlockQuantStorage

1.13.0 · Source

impl Display for BorrowError

1.13.0 · Source

impl Display for BorrowMutError

Source

impl Display for Box<dyn Op>

Source

impl Display for Box<dyn TypedOp>

Source

impl Display for regex_automata::dfa::onepass::BuildError

Source

impl Display for regex_automata::hybrid::error::BuildError

Source

impl Display for regex_automata::meta::error::BuildError

Source

impl Display for regex_automata::nfa::thompson::error::BuildError

Source

impl Display for aho_corasick::util::error::BuildError

Source

impl Display for ByteStr

Source

impl Display for ByteString

Source

impl Display for CacheError

Source

impl Display for CaseFoldError

1.34.0 · Source

impl Display for CharTryFromError

Source

impl Display for CollectionAllocErr

1.9.0 · Source

impl Display for DecodeUtf16Error

Source

impl Display for DeserializeError

1.87.0 · Source

impl Display for std::ffi::os_str::Display<'_>

1.0.0 · Source

impl Display for std::path::Display<'_>

Source

impl Display for EagerPackedInput

1.0.0 · Source

impl Display for std::io::error::Error

1.0.0 · Source

impl Display for tract_core::internal::tract_smallvec::alloc::fmt::Error

Source

impl Display for anyhow::Error

Source

impl Display for regex::error::Error

Source

impl Display for regex_syntax::ast::Error

Source

impl Display for regex_syntax::error::Error

Source

impl Display for regex_syntax::hir::Error

Source

impl Display for serde_core::de::value::Error

Source

impl Display for erased_serde::error::Error

1.60.0 · Source

impl Display for core::io::error::ErrorKind

Source

impl Display for regex_syntax::ast::ErrorKind

Source

impl Display for regex_syntax::hir::ErrorKind

1.20.0 · Source

impl Display for core::char::EscapeDebug

1.39.0 · Source

impl Display for core::ascii::EscapeDefault

1.16.0 · Source

impl Display for core::char::EscapeDefault

1.16.0 · Source

impl Display for core::char::EscapeUnicode

1.0.0 · Source

impl Display for ExitStatus

Source

impl Display for ExitStatusError

Source

impl Display for FftDirection

1.69.0 · Source

impl Display for FromBytesUntilNulError

1.17.0 · Source

impl Display for FromBytesWithNulError

1.0.0 · Source

impl Display for FromUtf8Error

1.0.0 · Source

impl Display for FromUtf16Error

1.58.0 · Source

impl Display for FromVecWithNulError

1.86.0 · Source

impl Display for GetDisjointMutError

Source

impl Display for GroupInfoError

Source

impl Display for Hir

Print a display representation of this Hir.

The result of this is a valid regular expression pattern string.

This implementation uses constant stack space and heap space proportional to the size of the Hir.

1.34.0 · Source

impl Display for Infallible

1.7.0 · Source

impl Display for IntoStringError

1.7.0 · Source

impl Display for IpAddr

1.0.0 · Source

impl Display for Ipv4Addr

1.0.0 · Source

impl Display for Ipv6Addr

Writes an Ipv6Addr, conforming to the canonical style described by RFC 5952.

1.0.0 · Source

impl Display for JoinPathsError

1.28.0 · Source

impl Display for LayoutError

Source

impl Display for Level

Source

impl Display for LevelFilter

Source

impl Display for LittleEndian

1.26.0 · Source

impl Display for Location<'_>

Source

impl Display for regex_automata::util::search::MatchError

Source

impl Display for aho_corasick::util::error::MatchError

Source

impl Display for NormalizeError

1.0.0 · Source

impl Display for NulError

Source

impl Display for PackedBlockQuantFormat

Source

impl Display for PackedExoticFact

Source

impl Display for PackedFormat

Source

impl Display for PackedI8K4

Source

impl Display for PackedMatrixStorage

Source

impl Display for PanelExtractInput

Source

impl Display for PanelExtractor

1.26.0 · Source

impl Display for PanicHookInfo<'_>

1.26.0 · Source

impl Display for PanicInfo<'_>

1.81.0 · Source

impl Display for PanicMessage<'_>

1.0.0 · Source

impl Display for ParseBoolError

1.20.0 · Source

impl Display for ParseCharError

1.0.0 · Source

impl Display for core::num::float_parse::ParseFloatError

Source

impl Display for tract_core::internal::tract_num_traits::ParseFloatError

1.0.0 · Source

impl Display for ParseIntError

Source

impl Display for ParseLevelError

Source

impl Display for regex_automata::util::primitives::PatternIDError

Source

impl Display for aho_corasick::util::primitives::PatternIDError

Source

impl Display for PatternSetInsertError

Available on crate feature alloc only.
Source

impl Display for PlainStorage

1.0.0 · Source

impl Display for RecvError

1.15.0 · Source

impl Display for std::sync::mpsc::RecvTimeoutError

Source

impl Display for regex::regex::bytes::Regex

Source

impl Display for regex::regex::string::Regex

Source

impl Display for ScanError

Source

impl Display for SerializeError

Source

impl Display for SetLoggerError

Source

impl Display for ShapeError

Source

impl Display for SliceInfoElem

Source

impl Display for SmallIndexError

1.0.0 · Source

impl Display for SocketAddr

1.0.0 · Source

impl Display for SocketAddrV4

1.0.0 · Source

impl Display for SocketAddrV6

Source

impl Display for StartError

Source

impl Display for regex_automata::util::primitives::StateIDError

Source

impl Display for aho_corasick::util::primitives::StateIDError

1.0.0 · Source

impl Display for String

1.7.0 · Source

impl Display for StripPrefixError

Source

impl Display for Symbol

1.8.0 · Source

impl Display for SystemTimeError

Source

impl Display for TDim

1.16.0 · Source

impl Display for ToLowercase

Source

impl Display for ToTitlecase

1.16.0 · Source

impl Display for ToUppercase

Source

impl Display for TooEarly

1.59.0 · Source

impl Display for TryFromCharError

1.66.0 · Source

impl Display for TryFromFloatSecsError

1.34.0 · Source

impl Display for TryFromIntError

1.35.0 · Source

impl Display for TryFromSliceError

1.89.0 · Source

impl Display for std::fs::TryLockError

1.0.0 · Source

impl Display for std::sync::mpsc::TryRecvError

1.57.0 · Source

impl Display for TryReserveError

Source

impl Display for UnicodeWordBoundaryError

Source

impl Display for UnicodeWordError

Source

impl Display for UnorderedKeyError

1.0.0 · Source

impl Display for Utf8Error

1.0.0 · Source

impl Display for VarError

Source

impl Display for WouldBlock

1.56.0 · Source

impl Display for WriterPanicked

Source

impl Display for bf16

Available on non-SPIR-V only.
1.0.0 · Source

impl Display for bool

1.0.0 · Source

impl Display for char

Source

impl Display for dyn Expected + '_

1.0.0 · Source

impl Display for f16

Source

impl Display for f16

Available on non-SPIR-V only.
1.0.0 · Source

impl Display for f32

1.0.0 · Source

impl Display for f64

1.0.0 · Source

impl Display for i8

1.0.0 · Source

impl Display for i16

1.0.0 · Source

impl Display for i32

1.0.0 · Source

impl Display for i64

1.0.0 · Source

impl Display for i128

1.0.0 · Source

impl Display for isize

1.0.0 · Source

impl Display for str

1.0.0 · Source

impl Display for u8

1.0.0 · Source

impl Display for u16

1.0.0 · Source

impl Display for u32

1.0.0 · Source

impl Display for u64

1.0.0 · Source

impl Display for u128

1.0.0 · Source

impl Display for usize

Source

impl<'a, I> Display for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Display,

Source

impl<'a, R, G, T> Display for MappedReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, G, T> Display for ReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::mutex::MappedMutexGuard<'a, R, T>
where R: RawMutex + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::rwlock::MappedRwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::rwlock::MappedRwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::mutex::MutexGuard<'a, R, T>
where R: RawMutex + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::rwlock::RwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for RwLockUpgradableReadGuard<'a, R, T>
where R: RawRwLockUpgrade + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::rwlock::RwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,

1.60.0 · Source

impl<'a> Display for EscapeAscii<'a>

1.34.0 · Source

impl<'a> Display for tract_core::internal::tract_smallvec::alloc::str::EscapeDebug<'a>

1.34.0 · Source

impl<'a> Display for tract_core::internal::tract_smallvec::alloc::str::EscapeDefault<'a>

1.34.0 · Source

impl<'a> Display for tract_core::internal::tract_smallvec::alloc::str::EscapeUnicode<'a>

Source

impl<'a> Display for Unexpected<'a>

Source

impl<A, D> Display for ArrayRef<A, D>
where A: Display, D: Dimension,

Format the array reference using Display and apply the formatting parameters used to each element.

The array is shown in multiline style.

Source

impl<A, S, D> Display for ArrayBase<S, D>
where A: Display, D: Dimension, S: Data<Elem = A>,

Format the array using Display and apply the formatting parameters used to each element.

The array is shown in multiline style.

Source

impl<A, S, V> Display for ConvertError<A, S, V>
where A: Display, S: Display, V: Display,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

Source

impl<B> Display for BitSet<B>
where B: BitBlock,

Source

impl<B> Display for BitVec<B>
where B: BitBlock,

1.0.0 · Source

impl<B> Display for Cow<'_, B>
where B: Display + ToOwned + ?Sized, <B as ToOwned>::Owned: Display,

Source

impl<E> Display for Err<E>
where E: Debug,

Source

impl<E> Display for ParseComplexError<E>
where E: Display,

Source

impl<E> Display for Report<E>
where E: Error,

Source

impl<F, O> Display for Graph<F, O>
where F: Fact + Clone + 'static, O: Debug + Display + AsRef<dyn Op> + AsMut<dyn Op> + Clone + 'static,

Source

impl<F: Fact, O: Display> Display for Node<F, O>

1.93.0 · Source

impl<F> Display for FromFn<F>
where F: Fn(&mut Formatter<'_>) -> Result<(), Error>,

Source

impl<I, F> Display for FormatWith<'_, I, F>
where I: Iterator, F: FnMut(<I as Iterator>::Item, &mut dyn FnMut(&dyn Display) -> Result<(), Error>) -> Result<(), Error>,

Source

impl<I> Display for nom::error::Error<I>
where I: Display,

The Display implementation allows the std::error::Error implementation

Source

impl<I> Display for ExactlyOneError<I>
where I: Iterator,

Source

impl<I> Display for VerboseError<I>
where I: Display,

Source

impl<K, V, S, A> Display for OccupiedError<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,

Source

impl<L, R> Display for Either<L, R>
where L: Display, R: Display,

Source

impl<O> Display for F32<O>
where O: ByteOrder,

Source

impl<O> Display for F64<O>
where O: ByteOrder,

Source

impl<O> Display for I16<O>
where O: ByteOrder,

Source

impl<O> Display for I32<O>
where O: ByteOrder,

Source

impl<O> Display for I64<O>
where O: ByteOrder,

Source

impl<O> Display for I128<O>
where O: ByteOrder,

Source

impl<O> Display for Isize<O>
where O: ByteOrder,

Source

impl<O> Display for U16<O>
where O: ByteOrder,

Source

impl<O> Display for U32<O>
where O: ByteOrder,

Source

impl<O> Display for U64<O>
where O: ByteOrder,

Source

impl<O> Display for U128<O>
where O: ByteOrder,

Source

impl<O> Display for Usize<O>
where O: ByteOrder,

1.33.0 · Source

impl<Ptr> Display for Pin<Ptr>
where Ptr: Display,

Source

impl<Src, Dst> Display for AlignmentError<Src, Dst>
where Src: Deref, Dst: KnownLayout + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

Source

impl<Src, Dst> Display for SizeError<Src, Dst>
where Src: Deref, Dst: KnownLayout + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

Source

impl<Src, Dst> Display for ValidityError<Src, Dst>
where Dst: KnownLayout + TryFromBytes + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

1.0.0 · Source

impl<T, A> Display for Arc<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Box<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Rc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueArc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueRc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, B> Display for zerocopy::ref::def::Ref<B, T>

1.0.0 · Source

impl<T> Display for &T
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for &mut T
where T: Display + ?Sized,

Source

impl<T> Display for Complex<T>
where T: Display + Num + PartialOrd + Clone,

Source

impl<T> Display for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

1.28.0 · Source

impl<T> Display for NonZero<T>

1.0.0 · Source

impl<T> Display for PoisonError<T>

Source

impl<T> Display for std::sync::oneshot::RecvTimeoutError<T>

Source

impl<T> Display for ReentrantLockGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for core::cell::Ref<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for RefMut<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.74.0 · Source

impl<T> Display for Saturating<T>
where T: Display,

1.0.0 · Source

impl<T> Display for SendError<T>

Source

impl<T> Display for SendTimeoutError<T>

Source

impl<T> Display for ThinBox<T>
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for std::sync::poison::TryLockError<T>

Source

impl<T> Display for std::sync::oneshot::TryRecvError<T>

1.0.0 · Source

impl<T> Display for TrySendError<T>

Source

impl<T> Display for Unalign<T>
where T: Unaligned + Display,

1.10.0 · Source

impl<T> Display for Wrapping<T>
where T: Display,

1.0.0 · Source

impl<W> Display for IntoInnerError<W>