[][src]Struct tract_core::model::ShapeInfo

pub struct ShapeInfo {
    pub stream_info: Option<StreamInfo>,
    // some fields omitted
}

Fully determined dimension of a tensor.

Tensors in tract can have one streaming dimension. TDim generalize the regular tensor dimensions (usize) to arithmetic expressions of S, the (sometimes hypothetical) tensor length on the streaming axis.

Fields

stream_info: Option<StreamInfo>

Optional information for streaming tensors. None for regular tensors.

Methods

impl ShapeInfo[src]

pub fn rank(&self) -> usize[src]

Rank of the tensor.

pub fn dim(&self, i: usize) -> TDim[src]

Extended dimension of the i-th axis.

The TDim will wrap a plain integer for regular (non-streaming) tensors.

pub fn as_finite(&self) -> Option<&[usize]>[src]

Shape of the tensor, unless it is streaming.

pub fn iter<'a>(&'a self) -> impl Iterator<Item = TDim> + 'a[src]

Iterator over dimension of the shape.

pub fn to_tvec(&self) -> TVec<TDim>[src]

Convert the shape to an array of extended dimensions.

pub fn to_shape_fact(&self) -> ShapeFact[src]

Convert the shape to a fully determined shape fact.