Fact

Trait Fact 

pub trait Fact:
    Debug
    + Downcast
    + DynClone
    + DynEq
    + Send
    + Sync
    + 'static {
    // Required methods
    fn to_typed_fact(&self) -> TractResult<Cow<'_, TypedFact>>;
    fn compatible_with(&self, _other: &dyn Fact) -> bool;
    fn datum_type(&self) -> Option<DatumType>;

    // Provided method
    fn matches(
        &self,
        t: &Tensor,
        symbols: Option<&SymbolValues>,
    ) -> TractResult<bool> { ... }
}
Type information about a tensor: shape, and element type, in various state of determination.

Required Methods

fn to_typed_fact(&self) -> TractResult<Cow<'_, TypedFact>>

fn compatible_with(&self, _other: &dyn Fact) -> bool

Ensure that self is same type as another fact or a subtype

fn datum_type(&self) -> Option<DatumType>

Provided Methods

fn matches( &self, t: &Tensor, symbols: Option<&SymbolValues>, ) -> TractResult<bool>

Implementations

Source

impl dyn Fact

pub fn is<__T: Fact>(&self) -> bool

Returns true if the trait object wraps an object of type __T.

pub fn downcast<__T: Fact>(self: Box<Self>) -> Result<Box<__T>, Box<Self>>

Returns a boxed object from a boxed trait object if the underlying object is of type __T. Returns the original boxed trait if it isn’t.

pub fn downcast_rc<__T: Fact>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>

Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of type __T. Returns the original Rc-ed trait if it isn’t.

pub fn downcast_ref<__T: Fact>(&self) -> Option<&__T>

Returns a reference to the object within the trait object if it is of type __T, or None if it isn’t.

pub fn downcast_mut<__T: Fact>(&mut self) -> Option<&mut __T>

Returns a mutable reference to the object within the trait object if it is of type __T, or None if it isn’t.