Module array

Module array 

Re-exports

pub use self::dyn_slice::DynSlice;
pub use self::strided_slice::StridedSlice;

Modules

dyn_slice
strided_slice

Structs

DynTile
FiniteReshape
Gather
GatherElements
For every coordinate of indices, reads data at that same coordinate with axis replaced by the index value found there. The output has indices’ shape. A negative index counts from the end of axis. data and indices must have the same rank; off axis, indices may be smaller than data.
GatherNd
MultiBroadcastTo
OneHot
Pad
Range
ScatterElements
ScatterNd
Slice
Tile
Topk
Trilu
TypedConcat

Enums

PadMode
ScatterReduction