pub struct SimplePlan<F, O>where
F: Fact + Clone + 'static,
O: Debug + Display + AsRef<dyn Op> + AsMut<dyn Op> + Clone + 'static,{ /* private fields */ }Implementations
Sourceimpl<F, O> SimplePlan<F, O>
impl<F, O> SimplePlan<F, O>
Sourcepub fn new(
model: impl Into<Arc<Graph<F, O>>>,
) -> TractResult<Arc<SimplePlan<F, O>>>
pub fn new( model: impl Into<Arc<Graph<F, O>>>, ) -> TractResult<Arc<SimplePlan<F, O>>>
This contructor returns a plan that will compute all the model default outputs in one pass.
Sourcepub fn new_with_options(
model: impl Into<Arc<Graph<F, O>>>,
options: &RunOptions,
) -> TractResult<Arc<SimplePlan<F, O>>>
pub fn new_with_options( model: impl Into<Arc<Graph<F, O>>>, options: &RunOptions, ) -> TractResult<Arc<SimplePlan<F, O>>>
This contructor returns a plan that will compute all the model default outputs in one pass.
Sourcepub fn new_for_output(
model: Graph<F, O>,
output: OutletId,
) -> TractResult<Arc<SimplePlan<F, O>>>
👎Deprecated
pub fn new_for_output( model: Graph<F, O>, output: OutletId, ) -> TractResult<Arc<SimplePlan<F, O>>>
This contructor returns a plan that will compute the specified output.
Sourcepub fn new_for_outputs(
model: impl Into<Arc<Graph<F, O>>>,
outputs: &[OutletId],
) -> TractResult<Arc<SimplePlan<F, O>>>
👎Deprecated
pub fn new_for_outputs( model: impl Into<Arc<Graph<F, O>>>, outputs: &[OutletId], ) -> TractResult<Arc<SimplePlan<F, O>>>
This contructor returns a plan that will compute all specified outputs in one pass.
pub fn with_session_handler<H: SessionStateHandler + 'static>( self, session_handler: H, ) -> Self
pub fn new_for_outputs_and_deps( model: impl Into<Arc<Graph<F, O>>>, outputs: &[OutletId], deps: &[(usize, usize)], ) -> TractResult<Arc<SimplePlan<F, O>>>
👎Deprecated
pub fn build( model: impl Into<Arc<Graph<F, O>>>, options: &RunOptions, ) -> TractResult<SimplePlan<F, O>>
pub fn build_with_outputs_and_deps( model: impl Into<Arc<Graph<F, O>>>, outputs: &[OutletId], deps: &[(usize, usize)], options: &RunOptions, ) -> TractResult<SimplePlan<F, O>>
👎Deprecated
pub fn order_without_consts(&self) -> &[usize]
pub fn run(self: &Arc<Self>, inputs: TVec<TValue>) -> TractResult<TVec<TValue>>
pub fn model(&self) -> &Graph<F, O>
pub fn spawn(self: &Arc<Self>) -> TractResult<SimpleState<F, O>>