pub struct DenseView<'a> { /* private fields */ }Expand description
Immutable view into a Tensor verified to have dense storage.
Construction is the single point of failure (Tensor::as_dense() returns
Option). Once constructed, all data access is infallible with no
unwrap()/expect() on the dense codepath.
Implementations
Sourceimpl<'a> DenseView<'a>
impl<'a> DenseView<'a>
pub fn tensor(&self) -> &Tensor
pub fn datum_type(&self) -> DatumType
pub fn shape(&self) -> &[usize]
pub fn strides(&self) -> &[isize]
pub fn rank(&self) -> usize
pub fn len(&self) -> usize
pub fn as_bytes(&self) -> &'a [u8] ⓘ
pub fn layout(&self) -> &Layout
pub fn as_ptr<D>(&self) -> Result<*const D, Error>where
D: Datum,
pub unsafe fn as_ptr_unchecked<D>(&self) -> *const Dwhere
D: Datum,
pub fn as_slice<D>(&self) -> Result<&'a [D], Error>where
D: Datum,
pub unsafe fn as_slice_unchecked<D>(&self) -> &'a [D]where
D: Datum,
pub fn to_scalar<D>(&self) -> Result<&'a D, Error>where
D: Datum,
pub unsafe fn to_scalar_unchecked<D>(&self) -> &'a Dwhere
D: Datum,
pub fn to_array_view<D>(
&self,
) -> Result<ArrayBase<ViewRepr<&'a D>, Dim<IxDynImpl>>, Error>where
D: Datum,
pub unsafe fn to_array_view_unchecked<D>(
&self,
) -> ArrayBase<ViewRepr<&'a D>, Dim<IxDynImpl>>where
D: Datum,