Module transform

Module transform 

Structs

ConcretizeSymbolsConfig
FloatPrecisionConfig
Config for the float_precision transform.
FloatTranslatorConfig
Config for float precision transforms (f32_to_f16, f16_to_f32).
ModelTransformFactory
NodeFilter
Structured include/exclude filter for node names.

Traits

ModelTransform

Functions

build_float_translator
Build Float precision translator given a NodeFilter. If the filter is pass-through, all nodes will be translated during the transformation.
get_transform
Look up a transform by name, using default config.
get_transform_with_params
Look up a transform by name, deserializing config from the given deserializer.
parse_legacy_filter
Parse a legacy filter string ("!=..." / "==...") into a NodeFilter.
split_spec
Split a transform spec like "f32_to_f16(filter: \"!=layer.norm\")" into name and params.