pub enum MeshIndex {
XY,
IJ,
}Expand description
The indexing order for meshgrid; see there for more details.
Controls whether the first argument to meshgrid will fill the rows or columns of the outputs.
Variants
XY
Cartesian indexing.
The first argument of meshgrid will repeat over the columns of the output.
Note: this is the default in numpy.
IJ
Matrix indexing.
The first argument of meshgrid will repeat over the rows of the output.