Struct tract_core::model::ModelPatch
source · pub struct ModelPatch<F, O>where
F: Fact + Clone + 'static + Hash,
O: Display + Debug + AsRef<dyn Op> + AsMut<dyn Op> + Clone + 'static + Hash,{
pub context: Vec<String>,
pub dont_apply_twice: Option<String>,
pub model: Graph<F, O>,
pub inputs: HashMap<usize, usize>,
pub incoming: HashMap<OutletId, OutletId>,
pub shunt_outlet_by: HashMap<OutletId, OutletId>,
pub obliterate: Vec<usize>,
}Expand description
A change to apply to a model.
Actually structured around a model that represent the new nodes to be inserted, plus information about how to connect these new nodes to the pre-existing graph.
Fields
context: Vec<String>patch label for auditing and debugging
dont_apply_twice: Option<String>optimizer will ignore this patch in node to node loop if it was already encountered
model: Graph<F, O>the model-like ‘patch’ of nodes to add to the model
inputs: HashMap<usize, usize>map of replaced inputs (patch node id to model node id)
incoming: HashMap<OutletId, OutletId>map of patch inputs to model wires
shunt_outlet_by: HashMap<OutletId, OutletId>map of old wires to be replaced by new wires
obliterate: Vec<usize>operations to discard from the model
Implementations
sourceimpl<F, O> ModelPatch<F, O>where
F: Fact + Clone + 'static + Hash,
O: Display + Debug + AsRef<dyn Op> + AsMut<dyn Op> + Clone + 'static + Hash,
Graph<F, O>: SpecialOps<F, O>,
impl<F, O> ModelPatch<F, O>where
F: Fact + Clone + 'static + Hash,
O: Display + Debug + AsRef<dyn Op> + AsMut<dyn Op> + Clone + 'static + Hash,
Graph<F, O>: SpecialOps<F, O>,
pub fn new(s: impl Into<String>) -> Self
pub fn push_context(&mut self, s: impl Into<String>)
pub fn with_context(self, s: impl Into<String>) -> Self
pub fn is_empty(&self) -> bool
sourcepub fn tap_model(
&mut self,
model: &Graph<F, O>,
outlet: OutletId
) -> TractResult<OutletId>
pub fn tap_model(
&mut self,
model: &Graph<F, O>,
outlet: OutletId
) -> TractResult<OutletId>
Draw a tap from a preexisting node.
returns an OutletId usable in the little “patch” model
pub unsafe fn shunt_outside_unchecked(
&mut self,
outlet: OutletId,
by: OutletId
) -> TractResult<()>
sourcepub fn shunt_outside(
&mut self,
model: &Graph<F, O>,
outlet: OutletId,
by: OutletId
) -> TractResult<()>
pub fn shunt_outside(
&mut self,
model: &Graph<F, O>,
outlet: OutletId,
by: OutletId
) -> TractResult<()>
Replace an Outlet in the target model by one from the patch.
pub fn obliterate(&mut self, node: usize) -> TractResult<()>
sourcepub fn replace_single_op<IO: Into<O>>(
patched_model: &Graph<F, O>,
node: &Node<F, O>,
inputs: &[OutletId],
new_op: IO
) -> TractResult<ModelPatch<F, O>>
pub fn replace_single_op<IO: Into<O>>(
patched_model: &Graph<F, O>,
node: &Node<F, O>,
inputs: &[OutletId],
new_op: IO
) -> TractResult<ModelPatch<F, O>>
Convenience method creating a patch that replaces a single operation.
sourcepub fn fuse_with_next<IO: Into<O>>(
patched_model: &Graph<F, O>,
node: &Node<F, O>,
new_op: IO
) -> TractResult<ModelPatch<F, O>>
pub fn fuse_with_next<IO: Into<O>>(
patched_model: &Graph<F, O>,
node: &Node<F, O>,
new_op: IO
) -> TractResult<ModelPatch<F, O>>
Convenience method creating a patch that fuses an op with the next one.
sourcepub fn shunt_one_op(
patched_model: &Graph<F, O>,
node: &Node<F, O>
) -> TractResult<Option<ModelPatch<F, O>>>
pub fn shunt_one_op(
patched_model: &Graph<F, O>,
node: &Node<F, O>
) -> TractResult<Option<ModelPatch<F, O>>>
Convenience method creating a patch that shunts the given node.
pub fn rewire(
patched_model: &Graph<F, O>,
from: &[OutletId],
to: &[OutletId],
wiring: &dyn Fn(&mut Self, &[OutletId]) -> TractResult<TVec<OutletId>>
) -> TractResult<ModelPatch<F, O>>
sourcepub fn single_unary_op<IO: Into<O>>(
patched_model: &Graph<F, O>,
node: &Node<F, O>,
new_op: IO
) -> TractResult<ModelPatch<F, O>>
pub fn single_unary_op<IO: Into<O>>(
patched_model: &Graph<F, O>,
node: &Node<F, O>,
new_op: IO
) -> TractResult<ModelPatch<F, O>>
Convenience method creating a patch that replace a single unary operation.
sourcepub fn intercept<IO: Into<O>>(
patched_model: &Graph<F, O>,
outlet: OutletId,
name: impl Into<String>,
new_op: IO,
fact: F
) -> TractResult<ModelPatch<F, O>>
pub fn intercept<IO: Into<O>>(
patched_model: &Graph<F, O>,
outlet: OutletId,
name: impl Into<String>,
new_op: IO,
fact: F
) -> TractResult<ModelPatch<F, O>>
Convenience method creating a patch that insert an unary op on an outlet.
sourcepub fn apply(self, target: &mut Graph<F, O>) -> TractResult<()>
pub fn apply(self, target: &mut Graph<F, O>) -> TractResult<()>
Apply all changes in the patch to the target model.
Methods from Deref<Target = Graph<F, O>>
pub fn add_source(
&mut self,
name: impl Into<String>,
fact: F
) -> TractResult<OutletId>
pub fn add_node(
&mut self,
name: impl Into<String>,
op: impl Into<O>,
output_facts: TVec<F>
) -> TractResult<usize>
sourcepub fn add_edge(&mut self, outlet: OutletId, inlet: InletId) -> TractResult<()>
pub fn add_edge(&mut self, outlet: OutletId, inlet: InletId) -> TractResult<()>
Connect a node outlet to a node inlet.
sourcepub fn input_outlets(&self) -> TractResult<&[OutletId]>
pub fn input_outlets(&self) -> TractResult<&[OutletId]>
Get model inputs.
sourcepub fn set_input_outlets(&mut self, inputs: &[OutletId]) -> TractResult<()>
pub fn set_input_outlets(&mut self, inputs: &[OutletId]) -> TractResult<()>
Change model inputs.
sourcepub fn set_input_names(
&mut self,
inputs: impl IntoIterator<Item = impl AsRef<str>>
) -> TractResult<()>
pub fn set_input_names(
&mut self,
inputs: impl IntoIterator<Item = impl AsRef<str>>
) -> TractResult<()>
Set model inputs by the node name.
sourcepub fn input_fact(&self, ix: usize) -> TractResult<&F>
pub fn input_fact(&self, ix: usize) -> TractResult<&F>
Get the ix-th input tensor type information.
sourcepub fn input_fact_mut(&mut self, ix: usize) -> TractResult<&mut F>
pub fn input_fact_mut(&mut self, ix: usize) -> TractResult<&mut F>
Get the ix-th input tensor type information, mutably.
sourcepub fn set_input_fact(&mut self, input: usize, fact: F) -> TractResult<()>
pub fn set_input_fact(&mut self, input: usize, fact: F) -> TractResult<()>
Set the ix-th input tensor type information.
sourcepub fn output_outlets(&self) -> TractResult<&[OutletId]>
pub fn output_outlets(&self) -> TractResult<&[OutletId]>
Get model outputs.
sourcepub fn auto_outputs(&mut self) -> TractResult<()>
pub fn auto_outputs(&mut self) -> TractResult<()>
Guess outputs from the topology: node or nodes with no successors.
sourcepub fn set_output_outlets(&mut self, outputs: &[OutletId]) -> TractResult<()>
pub fn set_output_outlets(&mut self, outputs: &[OutletId]) -> TractResult<()>
Change model outputs.
sourcepub fn set_output_names(
&mut self,
outputs: impl IntoIterator<Item = impl AsRef<str>>
) -> TractResult<()>
pub fn set_output_names(
&mut self,
outputs: impl IntoIterator<Item = impl AsRef<str>>
) -> TractResult<()>
Set model outputs by node names.
sourcepub fn output_fact(&self, ix: usize) -> TractResult<&F>
pub fn output_fact(&self, ix: usize) -> TractResult<&F>
Get the ix-th input tensor type information.
sourcepub fn output_fact_mut(&mut self, ix: usize) -> TractResult<&mut F>
pub fn output_fact_mut(&mut self, ix: usize) -> TractResult<&mut F>
Get the ix-th input tensor type information, mutably.
sourcepub fn set_output_fact(&mut self, output: usize, fact: F) -> TractResult<()>
pub fn set_output_fact(&mut self, output: usize, fact: F) -> TractResult<()>
Set the ix-th output tensor type information.
sourcepub fn node_names(&self) -> impl Iterator<Item = &str>
pub fn node_names(&self) -> impl Iterator<Item = &str>
Iterate over all node names.
pub fn node_id_by_name(&self, name: &str) -> TractResult<usize>
sourcepub fn node_by_name(&self, name: impl AsRef<str>) -> TractResult<&Node<F, O>>
pub fn node_by_name(&self, name: impl AsRef<str>) -> TractResult<&Node<F, O>>
Find a node by its name.
sourcepub fn node_by_name_mut(
&mut self,
name: impl AsRef<str>
) -> TractResult<&mut Node<F, O>>
pub fn node_by_name_mut(
&mut self,
name: impl AsRef<str>
) -> TractResult<&mut Node<F, O>>
Borrow mutably a node by its name.
pub fn rename_node(&mut self, id: usize, name: &str) -> TractResult<()>
sourcepub fn node_facts(&self, id: usize) -> TractResult<(TVec<&F>, TVec<&F>)>
pub fn node_facts(&self, id: usize) -> TractResult<(TVec<&F>, TVec<&F>)>
Get input and output tensor information for a node.
sourcepub fn node_input_facts(&self, node_id: usize) -> TractResult<TVec<&F>>
pub fn node_input_facts(&self, node_id: usize) -> TractResult<TVec<&F>>
Get input tensor information for a node.
sourcepub fn node_output_facts(&self, node_id: usize) -> TractResult<TVec<&F>>
pub fn node_output_facts(&self, node_id: usize) -> TractResult<TVec<&F>>
Get output tensor information for a node.
sourcepub fn outlet_fact(&self, outlet: OutletId) -> TractResult<&F>
pub fn outlet_fact(&self, outlet: OutletId) -> TractResult<&F>
Get tensor information for a single outlet.
sourcepub fn outlet_fact_mut(&mut self, outlet: OutletId) -> TractResult<&mut F>
pub fn outlet_fact_mut(&mut self, outlet: OutletId) -> TractResult<&mut F>
Get tensor information for a single outlet.
sourcepub fn outlets_fact_mut(
&mut self,
outlets: &[OutletId]
) -> TractResult<TVec<&mut F>>
pub fn outlets_fact_mut(
&mut self,
outlets: &[OutletId]
) -> TractResult<TVec<&mut F>>
Get multiple mutable tensor information for outlets.
sourcepub fn set_outlet_fact(&mut self, outlet: OutletId, fact: F) -> TractResult<()>
pub fn set_outlet_fact(&mut self, outlet: OutletId, fact: F) -> TractResult<()>
Set tensor information for a single outlet.
sourcepub fn outlet_label(&self, outlet: OutletId) -> Option<&str>
pub fn outlet_label(&self, outlet: OutletId) -> Option<&str>
Get label for an outlet.
sourcepub fn set_outlet_label(
&mut self,
outlet: OutletId,
label: String
) -> TractResult<()>
pub fn set_outlet_label(
&mut self,
outlet: OutletId,
label: String
) -> TractResult<()>
Set label for an outlet.
sourcepub fn find_outlet_label(&self, label: &str) -> Option<OutletId>
pub fn find_outlet_label(&self, label: &str) -> Option<OutletId>
Find outlet by label.
sourcepub fn eval_order(&self) -> TractResult<Vec<usize>>
pub fn eval_order(&self) -> TractResult<Vec<usize>>
Computes an evalutation order for the graph inputs and outputs
sourcepub fn check_edges(&self) -> TractResult<()>
pub fn check_edges(&self) -> TractResult<()>
Performs a sanity check on network connections.
pub fn single_prec(&self, id: usize) -> TractResult<Option<&Node<F, O>>>
pub fn single_prec_at(
&self,
id: usize,
count: usize
) -> TractResult<Option<&Node<F, O>>>
pub fn single_succ_at(
&self,
id: usize,
count: usize
) -> TractResult<Option<&Node<F, O>>>
pub fn single_succ(&self, id: usize) -> TractResult<Option<&Node<F, O>>>
pub fn outlet_successors(&self, outlet: OutletId) -> &[InletId]
pub fn add_const(
&mut self,
name: impl Into<String>,
v: impl IntoArcTensor
) -> TractResult<OutletId>
pub fn check_compact(&self) -> TractResult<()>
pub fn compact(&mut self) -> TractResult<()>
pub fn signature(&self) -> u64
pub fn check_consistency(&self) -> TractResult<()>
sourcepub fn declutter(&mut self) -> TractResult<()>
pub fn declutter(&mut self) -> TractResult<()>
Perform declutter passes on the network.
sourcepub fn optimize_with_session(
&mut self,
session: &mut OptimizerSession<'_>
) -> TractResult<()>
pub fn optimize_with_session(
&mut self,
session: &mut OptimizerSession<'_>
) -> TractResult<()>
Perform optimization passes on the model, using a given optimizer session.
pub fn concretize_dims(&self, values: &SymbolValues) -> TractResult<TypedModel>
sourcepub fn optimize(&mut self) -> TractResult<()>
pub fn optimize(&mut self) -> TractResult<()>
Translate the graph to locally optimized operators (LIR or MIR ops).
pub fn invariants(&self) -> TractResult<Invariants>