[−][src]Struct tract_core::plan::SimplePlan
Fields
model: Moutputs: Vec<OutletId>order: Vec<usize>flush_lists: Vec<TVec<usize>>Methods
impl<TI: TensorInfo, M: Borrow<Model<TI>>> SimplePlan<TI, M>[src]
pub fn new(model: M) -> TractResult<SimplePlan<TI, M>>[src]
This contructor returns a plan that will compute all the model default outputs in one pass.
pub fn new_for_output(
model: M,
output: OutletId
) -> TractResult<SimplePlan<TI, M>>[src]
model: M,
output: OutletId
) -> TractResult<SimplePlan<TI, M>>
This contructor returns a plan that will compute the specified output.
pub fn new_for_outputs(
model: M,
outputs: &[OutletId]
) -> TractResult<SimplePlan<TI, M>>[src]
model: M,
outputs: &[OutletId]
) -> TractResult<SimplePlan<TI, M>>
This contructor returns a plan that will compute all specified outputs in one pass.
pub fn run(&self, inputs: TVec<Tensor>) -> TractResult<TVec<Arc<Tensor>>>[src]
pub fn model(&self) -> &Model<TI>[src]