pub trait Runnable:
Any
+ Downcast
+ Debug
+ Send
+ Sync
+ 'static {
// Required methods
fn spawn(&self) -> TractResult<Box<dyn State>>;
fn typed_plan(&self) -> Option<&Arc<TypedSimplePlan>>;
fn typed_model(&self) -> Option<&Arc<TypedModel>>;
// Provided methods
fn run(&self, inputs: TVec<TValue>) -> TractResult<TVec<TValue>> { ... }
fn input_count(&self) -> usize { ... }
fn output_count(&self) -> usize { ... }
fn input_fact(&self, ix: usize) -> TractResult<&TypedFact> { ... }
fn output_fact(&self, ix: usize) -> TractResult<&TypedFact> { ... }
fn properties(&self) -> &HashMap<String, Arc<Tensor>> { ... }
}Required Methods
fn spawn(&self) -> TractResult<Box<dyn State>>
fn typed_plan(&self) -> Option<&Arc<TypedSimplePlan>>
fn typed_model(&self) -> Option<&Arc<TypedModel>>
Provided Methods
fn run(&self, inputs: TVec<TValue>) -> TractResult<TVec<TValue>>
fn input_count(&self) -> usize
fn output_count(&self) -> usize
fn input_fact(&self, ix: usize) -> TractResult<&TypedFact>
fn output_fact(&self, ix: usize) -> TractResult<&TypedFact>
fn properties(&self) -> &HashMap<String, Arc<Tensor>>
Implementations
Sourceimpl dyn Runnable
impl dyn Runnable
Sourcepub fn is<__T: Runnable>(&self) -> bool
pub fn is<__T: Runnable>(&self) -> bool
Returns true if the trait object wraps an object of type __T.
Sourcepub fn downcast<__T: Runnable>(self: Box<Self>) -> Result<Box<__T>, Box<Self>>
pub fn downcast<__T: Runnable>(self: Box<Self>) -> Result<Box<__T>, Box<Self>>
Returns a boxed object from a boxed trait object if the underlying object is of type
__T. Returns the original boxed trait if it isn’t.
Sourcepub fn downcast_rc<__T: Runnable>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>
pub fn downcast_rc<__T: Runnable>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>
Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of
type __T. Returns the original Rc-ed trait if it isn’t.
Sourcepub fn downcast_ref<__T: Runnable>(&self) -> Option<&__T>
pub fn downcast_ref<__T: Runnable>(&self) -> Option<&__T>
Returns a reference to the object within the trait object if it is of type __T, or
None if it isn’t.
Sourcepub fn downcast_mut<__T: Runnable>(&mut self) -> Option<&mut __T>
pub fn downcast_mut<__T: Runnable>(&mut self) -> Option<&mut __T>
Returns a mutable reference to the object within the trait object if it is of type
__T, or None if it isn’t.