State

Trait State 

pub trait State:
    Any
    + Downcast
    + Debug
    + 'static {
    // Required methods
    fn run(&mut self, inputs: TVec<TValue>) -> TractResult<TVec<TValue>>;
    fn runnable(&self) -> &dyn Runnable;
    fn initializable_states_count(&self) -> usize;
    fn get_states_facts(&self) -> Vec<TypedFact>;
    fn init_state(&mut self, states: &[TValue]) -> TractResult<()>;
    fn get_states(&self) -> TractResult<Vec<TValue>>;
    fn freeze(&self) -> Box<dyn FrozenState>;

    // Provided methods
    fn input_count(&self) -> usize { ... }
    fn output_count(&self) -> usize { ... }
}

Required Methods

fn run(&mut self, inputs: TVec<TValue>) -> TractResult<TVec<TValue>>

fn runnable(&self) -> &dyn Runnable

fn initializable_states_count(&self) -> usize

fn get_states_facts(&self) -> Vec<TypedFact>

fn init_state(&mut self, states: &[TValue]) -> TractResult<()>

fn get_states(&self) -> TractResult<Vec<TValue>>

fn freeze(&self) -> Box<dyn FrozenState>

Provided Methods

Implementations

Source

impl dyn State

pub fn is<__T: State>(&self) -> bool

Returns true if the trait object wraps an object of type __T.

pub fn downcast<__T: State>(self: Box<Self>) -> Result<Box<__T>, Box<Self>>

Returns a boxed object from a boxed trait object if the underlying object is of type __T. Returns the original boxed trait if it isn’t.

pub fn downcast_rc<__T: State>(self: Rc<Self>) -> Result<Rc<__T>, Rc<Self>>

Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of type __T. Returns the original Rc-ed trait if it isn’t.

pub fn downcast_ref<__T: State>(&self) -> Option<&__T>

Returns a reference to the object within the trait object if it is of type __T, or None if it isn’t.

pub fn downcast_mut<__T: State>(&mut self) -> Option<&mut __T>

Returns a mutable reference to the object within the trait object if it is of type __T, or None if it isn’t.

Implementors