Structs
- Concretize
Symbols Config - Float
Precision Config - Config for the
float_precisiontransform. - Float
Translator Config - Config for float precision transforms (f32_to_f16, f16_to_f32).
- Model
Transform Factory - Node
Filter - Structured include/exclude filter for node names.
Traits
Functions
- build_
float_ translator - Build Float precision translator given a
NodeFilter. If the filter is pass-through, all nodes will be translated during the transformation. - get_
transform - Look up a transform by name, using default config.
- get_
transform_ with_ params - Look up a transform by name, deserializing config from the given deserializer.
- parse_
legacy_ filter - Parse a legacy filter string (
"!=..."/"==...") into aNodeFilter. - split_
spec - Split a transform spec like
"f32_to_f16(filter: \"!=layer.norm\")"into name and params.